/*
* This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/bonsai
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
*               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
*               Marian Pohling, Lukas Twardon, Lukas Kettenbach
*/
package de.unibi.airobots.bonsai.actuators;

import de.unibi.airobots.bonsai.core.Actuator;
import de.unibi.airobots.btl.data.Type;
import de.unibi.airobots.btl.data.Type.NoSourceDocumentException;
import java.io.IOException;

/**
 * Generic interface to control a active memory.
 * 
 * @param <T> BTL type that is inserted or replaced by this actuator.
 * 
 * @author lkettenb
 */
public interface BtlMemoryActuator<T extends Type> extends Actuator {
    
    /**
     * Insert a new object into the active memory.
     * 
     * @param object Object that will be inserted into the memory.
     * @param type Class object from the desired type.
     * 
     * @throws IOException 
     */
    void insert(T object, Class<? extends Type> type) throws IOException;
    
    /**
     * Replace/update an existing object.
     * 
     * @param object Object that will replaced.
     * 
     * @throws IOException 
     * @throws NoSourceDocumentException 
     */
    void replace(T object) throws IOException, NoSourceDocumentException;
}
