/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.core.configuration;

import java.util.Map;

/**
 * Basic configuration result returned by configuration parsers.
 * 
 * @author jwienke
 */
public abstract class ConfiguredCoreObject {

    private String key;
    private Map<String, String> options;
    private String factoryClassName;

    /**
     * Constructor.
     */
    public ConfiguredCoreObject() {
        super();
    }

    /**
     * Returns the key specified in the configuration.
     * 
     * @return key
     */
    public String getKey() {
        return key;
    }

    /**
     * Sets the key specified in the configuration.
     * 
     * @param key
     *            key
     */
    public void setKey(String key) {
        this.key = key;
    }

    /**
     * Returns the key-value style options for this core object specified in the
     * config.
     * 
     * @return options
     */
    public Map<String, String> getOptions() {
        return options;
    }

    /**
     * Sets the key-value style options for this core object specified in the
     * config.
     * 
     * @param options
     *            options
     */
    public void setOptions(Map<String, String> options) {
        this.options = options;
    }

    /**
     * Returns the fully specified class name of the factory that shall produce
     * this core object as specified in the config.
     * 
     * @return factory class name
     */
    public String getFactoryClassName() {
        return factoryClassName;
    }

    /**
     * Stes the fully specified class name of the factory that shall produce
     * this core object as specified in the config.
     * 
     * @param factoryClassName
     *            factory class name
     */
    public void setFactoryClassName(String factoryClassName) {
        this.factoryClassName = factoryClassName;
    }

}
