/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.examples;

import java.io.IOException;
import java.net.URL;

import org.apache.log4j.BasicConfigurator;

import de.unibi.airobots.bonsai.core.BonsaiManager;
import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.core.SensorListener;
import de.unibi.airobots.btl.data.LaserData;
import de.unibi.airobots.btl.data.SpeedData;

public class OpenDoorTest {

    static double[] oldValues = null;
    static int scanCount = 361;

    /**
     * Main method.
     * 
     * @param args
     *            command line arguments
     * @throws Exception
     *             error
     */
    public static void main(String[] args) throws Exception {
        // Not neccessary for this example (too much information ...)
        //BasicConfigurator.configure();

        try {

            URL configUrl =
                    SimpleXcfSensorTest.class.getResource("copyloader.xml");
            if (configUrl == null) {
                System.err.println("Config not found.");
                System.exit(1);
            }

            BonsaiManager.getInstance().configure(configUrl.toURI());

            System.out.println("Can create laser data subscriber: "
                    + BonsaiManager.getInstance().canCreateSensor(
                            "LaserSensor", LaserData.class));

            Sensor<LaserData> laserSensor =
                    BonsaiManager.getInstance().createSensor("LaserSensor",
                            LaserData.class);

            final Sensor<SpeedData> speedSensor =
                    BonsaiManager.getInstance().createSensor("SpeedSensor",
                            SpeedData.class);

            laserSensor.addSensorListener(new SensorListener<LaserData>() {

                @Override
                public void newDataAvailable(LaserData newData) {


                    try {
                        if (speedSensor.readLast().getSpeedTranslation() == 0) {
                            double[] scanValues = newData.getScanValues();

                            if (oldValues == null) {
                                oldValues = scanValues;
                            } else {
                                double error = 0;
                                for (int i = scanCount / 2 - 5; i < scanCount / 2 + 5; i++) {
                                    // System.out.println(scanValues[i]);
                                    error = +oldValues[i] - scanValues[i];
                                }
                                error = error / 10;
                                if (error == 0)
                                    return;

                                if (error < 0 && Math.abs(error) > 0.1)
                                    System.out.println("#### door open????? ");
                                if (error > 0 && Math.abs(error) > 0.1)
                                    System.out.println("#### door closed????? ");
                                oldValues = scanValues;
                                System.out.println("## error " + error);
                            }

                        }
                    } catch (IOException e) {
                        e.printStackTrace();
                    } catch (InterruptedException e) {
                        e.printStackTrace();
                    }
                }

            });

            while (true) {
                // System.out.println("########## test ###############");
                // System.out.println(laserSensor.readLast());
                // System.out.println("##### teste ende ##### ");
                // CHECKSTYLE:OFF
                // Thread.sleep(500);
                // CHECKSTYLE:ON
            }

            // CHECKSTYLE:OFF
        } catch (Exception e) {
            // CHECKSTYLE:ON
            e.printStackTrace();
            System.exit(1);
        }

    }

}
