/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.skills;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URI;
import java.net.URL;
import org.apache.commons.scxml.io.SCXMLParser;
import org.apache.commons.scxml.model.ModelException;
import org.apache.commons.scxml.model.SCXML;
import org.apache.log4j.Logger;
import org.xml.sax.ErrorHandler;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;

/**
 * @author nkoester
 */
public class SCXMLDecoder {

    /**
     * 
     */
    private SCXML scxml;

    private SCXMLValidator scxmlValidator;
    
  
    /**
     * The log.
     */
    private static final Logger LOGGER = Logger.getLogger(SCXMLDecoder.class);

    /**
     * 
     */
    public SCXMLDecoder() {
        scxmlValidator = new SCXMLValidator();
    }

    
//    public SCXML parseAndValidateSCXML2(String pathToSCXML) {
//        parseAndValidateSCXML(pathToSCXML);
//        return getScxml();
//    }
    
    /**
     * @param pathToSCXML
     * @return
     * 
     *         TODO: handle errors correctly ...
     * 
     * 
     */
    public boolean parseAndValidateSCXML(String pathToSCXML) {

        // parsing SCXML
        // TODO: lookup if there is any alternative for error handling in the
        // parsing process ...
        ErrorHandler errorHandler = new ErrorHandler() {

            @Override
            public void warning(SAXParseException exception)
                    throws SAXException {
                LOGGER.warn("warning!");
            }

            @Override
            public void fatalError(SAXParseException exception)
                    throws SAXException {
                LOGGER.fatal("fatal!");
            }

            @Override
            public void error(SAXParseException exception) throws SAXException {
                LOGGER.error("err!");
            }
        };

        // the actual parsing of the SCXML
        try {
            URI scxmlURI = new URI("file:" + pathToSCXML);
            URL scxmlURL = scxmlURI.toURL();
            scxml = SCXMLParser.parse(scxmlURL, errorHandler);
        } catch (MalformedURLException e) {
            LOGGER.error("Exception while digesting SCXML: "
                    + e.toString());
            return false;
        } catch (IOException e) {
            LOGGER.error("Exception while digesting SCXML: "
                    + e.toString());
            return false;
        } catch (SAXException e) {
            LOGGER.error("Exception while digesting SCXML: "
                    + e.toString());
            return false;
        } catch (ModelException e) {
            LOGGER.error("Exception while digesting SCXML: "
                    + e.toString());
            return false;
        } catch (Throwable t) {
            LOGGER.error("Exception while digesting SCXML: "
                    + t.toString());
            return false;
        }

        LOGGER.debug("SCXML digesting successful!");

        // checking if the states defined in the given SCXML are valid
        return scxmlValidator.validateSCXML(scxml);
    }
    
    public SCXML getScxml() {
        return scxml;
    }

    
    public void setScxml(SCXML scxml) {
        this.scxml = scxml;
    }
}
