/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.yarp;

import java.util.HashMap;
import java.util.Map;

/**
 *
 * @author cdondrup
 */
public abstract class ReconnectableManager<R> {

    /**
     * Default checking interval for Yarp ports in ms.
     */
    public static final long DEFAULT_CHECK_INTERVAL_IN_MS = 5000;

    /**
     * Initialize a Yarp port with the given name.
     *
     * @param portName
     *            Name of the Yarp port to initialize
     * @param connectTo The name of the port to connect to
     */
    public void initializeYarpPort(String portName, String connectTo)
    {
        Map<String,String> portMap = new HashMap<String,String>();
        portMap.put(portName,connectTo);
        initializeYarpPorts(portMap);
    }

    /**
     * Initializes the given list of Yarp port names.
     *
     * @param portNames
     *            Yarp ports to initially connect to.
     */
    public abstract void initializeYarpPorts(Map<String,String> portMap);

    /**
     * Initializes a new R with its first Yarp port and then manages it for the
     * lifetime of this class.
     *
     * @param cls The Yarp port Class to manage
     * @param reconnectable
     *            reconnectable to initialize
     */
    public abstract void initializeAndManage(Class cls, R reconnectable);

}
